=====
Space
=====

The module includes classes and routines for operations involving points, pointclouds and reference
frames in Euclidean space.

.. automodule:: sigmaepsilon.mesh.space
    :members:
 